//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[Hora](index.md)/[yaku](yaku.md)

# yaku

[common]\

@EncodeDefault

val [yaku](yaku.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../../mahjongutils.yaku/-yaku/index.md)&gt;

役种
